import React, {
  PropTypes,
} from 'react';

import {
  Text, TouchableWithoutFeedback, View,
} from 'react-native';

import { noop } from '../helper';

const propTypes = {
  children: PropTypes.node,
  left: PropTypes.node,
  onPressLeft: PropTypes.func,
  onPressRight: PropTypes.func,
  right: PropTypes.node,
  style: View.propTypes.style,
};
const defaultProps = {
  left: '取消',
  right: '确定',
  onPressLeft: noop,
  onPressRight: noop,
  children: null,
  style: null,
};

function Header({
  children, left, onPressLeft, onPressRight, right, style,
}) {
  // 转义左侧
  if (typeof left === 'string') {
    left = <Text>{left}</Text>;
  }
  if (left.type === Text) {
    left = (
      <TouchableWithoutFeedback onPress={onPressLeft}>
        <View>{left}</View>
      </TouchableWithoutFeedback>
    );
  }

  // 转义右侧
  if (typeof right === 'string') {
    right = <Text>{right}</Text>;
  }
  if (right.type === Text) {
    right = (
      <TouchableWithoutFeedback onPress={onPressRight}>
        <View>{right}</View>
      </TouchableWithoutFeedback>
    );
  }

  // 渲染模板
  return (
    <View alignItems="center" flexDirection="row" justifyContent="space-between" minHeight={48} style={style}>
      {left}
      {children}
      {right}
    </View>
  );
}

Header.propTypes = propTypes;
Header.defaultProps = defaultProps;

export default Header;
